@@ -3,7 +3,7 @@ from typing import Callable
 import cv2
 
 
-def __default_draw_fps(fps):
+def _default_draw_fps(fps):
     return f"{int(fps)} FPS"
 
 class FpsDrawer:
@@ -11,7 +11,7 @@ class FpsDrawer:
     This class is used to draw the frames per secondn(fps) on the screen
     """
     
-    def __init__(self, draw_fps_fn:Callable[[float], str]=__default_draw_fps, org= (7, 70), fontFace=cv2.FONT_HERSHEY_SIMPLEX, fontScale=2, color= (100, 255, 0), thickness=3, lineType=cv2.LINE_AA) -> None:
+    def __init__(self, draw_fps_fn:Callable[[float], str]=_default_draw_fps, org= (7, 70), fontFace=cv2.FONT_HERSHEY_SIMPLEX, fontScale=2, color= (100, 255, 0), thickness=3, lineType=cv2.LINE_AA) -> None:
         
         self.__counter = -1
         self._start = time.perf_counter()
