@@ -5,6 +5,9 @@ import numpy as np
     
         
 class Model:
+    """
+    Inherit from the class to define your model
+    """
     
     def __init__(self) -> None:
         raise Exception("Cannot instanciate")
@@ -12,16 +15,17 @@ class Model:
     def predict(self, image: np.ndarray)->Option:
         raise NotImplementedError()
         
-    
-    def for_static_images(*args, **kwargs)->"Model":
-        raise NotImplementedError()
-    
-    def for_videos(*args, **kwargs)->"Model":
-        raise NotImplementedError()
-               
                
                
 class ModelOutput:
+
+    """
+    Inherit from this class to define your model output\n
+    use the to_dict method to generate a json dictionary representation\n
+    of you output. (For Apis)
+
+    Use the draw function to define how the output should be drawn onto the screen
+    """
     
     def __init__(self) -> None:
         raise Exception("Cannot instanciate")    
@@ -29,7 +33,7 @@ class ModelOutput:
     def to_dict(self)->dict:
         raise NotImplementedError()           
         
-    def draw(self, original_image:np.ndarray)->None:
+    def draw(self, image:np.ndarray)->None:
         raise NotImplementedError()           
         
           
\ No newline at end of file
